@@ -47,10 +47,7 @@ AbstractImportExportJob::AbstractImportExportJob(QObject *parent, ArchiveStorage
     , mTypeSelected(typeSelected)
     , mArchiveStorage(archiveStorage)
     , mIdentityManager(KIdentityManagement::IdentityManager::self())
-    , mTempDir(nullptr)
-    , mArchiveDirectory(nullptr)
     , mNumberOfStep(numberOfStep)
-    , mCreateResource(nullptr)
     , mIndex(-1)
     , mImportExportProgressIndicator(new ImportExportProgressIndicatorBase(this))
 {
@@ -271,8 +268,9 @@ void AbstractImportExportJob::convertRealPathToCollectionList(KConfigGroup &grou
 
 Akonadi::Collection::Id AbstractImportExportJob::convertPathToId(const QString &path)
 {
-    if (mHashConvertPathCollectionId.contains(path)) {
-        return mHashConvertPathCollectionId.value(path);
+    Akonadi::Collection::Id val = mHashConvertPathCollectionId.value(path, -1);
+    if (val != -1) {
+        return val;
     }
     const Akonadi::Collection::Id id = MailCommon::Util::convertFolderPathToCollectionId(path);
     if (id != -1) {
@@ -474,7 +472,7 @@ void AbstractImportExportJob::extractZipFile(const KArchiveFile *file, const QSt
     } else {
         QFile archiveFile(source + QLatin1Char('/') + file->name());
         if (!archiveFile.copy(destination + QLatin1Char('/') + file->name())) {
-            Q_EMIT error(i18n("Unable to copy file", file->name()));
+            Q_EMIT error(i18n("Unable to copy file %1", file->name()));
         }
     }
 }
