@@ -69,12 +69,6 @@ Q_SIGNALS:
     void needSynchronizeResource(const QString &name, const QString &identifier);
     void jobFinished();
 
-private Q_SLOTS:
-    void slotAllResourceSynchronized();
-    void slotSynchronizeInstanceDone(const QString &, const QString &identifier);
-    void slotSynchronizeInstanceFailed(const QString &instance);
-    void slotTaskCanceled();
-
 protected:
     virtual void slotNextStep();
 
@@ -121,19 +115,24 @@ protected:
 
     QString mTempDirName;
     Utils::StoredTypes mTypeSelected;
-    ArchiveStorage *mArchiveStorage;
-    KIdentityManagement::IdentityManager *mIdentityManager;
-    QTemporaryDir *mTempDir;
-    const KArchiveDirectory *mArchiveDirectory;
-    int mNumberOfStep;
-    PimCommon::CreateResource *mCreateResource;
+    ArchiveStorage *mArchiveStorage = nullptr;
+    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
+    QTemporaryDir *mTempDir = nullptr;
+    const KArchiveDirectory *mArchiveDirectory = nullptr;
+    int mNumberOfStep = -1;
+    PimCommon::CreateResource *mCreateResource = nullptr;
     QStringList mAgentPaths;
     QList<Utils::StoredType> mListStep;
-    int mIndex;
+    int mIndex = -1;
     static int sArchiveVersion;
 
 private:
-    ImportExportProgressIndicatorBase *mImportExportProgressIndicator;
+    void slotAllResourceSynchronized();
+    void slotSynchronizeInstanceDone(const QString &, const QString &identifier);
+    void slotSynchronizeInstanceFailed(const QString &instance);
+    void slotTaskCanceled();
+
+    ImportExportProgressIndicatorBase *mImportExportProgressIndicator = nullptr;
 };
 
 #endif // ABSTRACTIMPORTEXPORTJOB_H
