@@ -34,7 +34,6 @@ ExportAkregatorJob::ExportAkregatorJob(QObject *parent, Utils::StoredTypes typeS
 
 ExportAkregatorJob::~ExportAkregatorJob()
 {
-
 }
 
 void ExportAkregatorJob::start()
@@ -73,7 +72,7 @@ void ExportAkregatorJob::slotCheckBackupData()
         const QString akregatorDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/akregator");
         QDir akregatorDirectory(akregatorDir);
         if (akregatorDirectory.exists()) {
-            const bool akregatorDirAdded = archive()->addLocalDirectory(akregatorDir, Utils::dataPath() +  QLatin1String("/akregator"));
+            const bool akregatorDirAdded = archive()->addLocalDirectory(akregatorDir, Utils::dataPath() +  QLatin1String("akregator"));
             if (!akregatorDirAdded) {
                 Q_EMIT error(i18n("\"%1\" directory cannot be added to backup file.", akregatorDir));
             }
@@ -82,4 +81,3 @@ void ExportAkregatorJob::slotCheckBackupData()
     }
     Q_EMIT jobFinished();
 }
-
