@@ -47,8 +47,6 @@
 
 ExportMailJob::ExportMailJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep)
     : AbstractImportExportJob(parent, archiveStorage, typeSelected, numberOfStep)
-    , mArchiveTime(QDateTime::currentDateTime())
-    , mIndexIdentifier(0)
 {
 }
 
