@@ -55,10 +55,10 @@ public:
     void expunge(Akonadi::Collection::Id col, bool sync) override;
 
 private:
-    KIdentityManagement::IdentityManager *mIdentityManager;
-    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor;
-    Akonadi::EntityTreeModel *mEntityTreeModel;
-    Akonadi::EntityMimeTypeFilterModel *mCollectionModel;
+    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
+    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor = nullptr;
+    Akonadi::EntityTreeModel *mEntityTreeModel = nullptr;
+    Akonadi::EntityMimeTypeFilterModel *mCollectionModel = nullptr;
 };
 
 #endif
