@@ -52,15 +52,13 @@
 
 PimSettingsBackupRestore::PimSettingsBackupRestore(QObject *parent)
     : QObject(parent)
-    , mImportExportData(nullptr)
-    , mAction(Backup)
-    , mArchiveStorage(nullptr)
 {
 }
 
 PimSettingsBackupRestore::~PimSettingsBackupRestore()
 {
     delete mImportExportData;
+    mImportExportData = nullptr;
     QFile f(mExportedInfoFileName);
     if (f.exists()) {
         const bool removeFile = f.remove();
