@@ -41,8 +41,6 @@ public:
     void nextStep();
     void closeArchive();
     void setExportedInfoFileName(const QString &filename);
-private Q_SLOTS:
-    void slotJobFinished();
 
 Q_SIGNALS:
     void addInfo(const QString &);
@@ -60,8 +58,9 @@ protected:
     virtual bool continueToRestore();
 
     virtual void addExportProgressIndicator();
-    AbstractImportExportJob *mImportExportData;
+    AbstractImportExportJob *mImportExportData = nullptr;
 private:
+    void slotJobFinished();
     enum Action {
         Backup,
         Restore
@@ -77,8 +76,8 @@ private:
     QString mExportedInfoFileName;
     QHash<Utils::AppsType, Utils::importExportParameters> mStored;
     QHash<Utils::AppsType, Utils::importExportParameters>::const_iterator mStoreIterator;
-    Action mAction;
-    ArchiveStorage *mArchiveStorage;
+    Action mAction = Backup;
+    ArchiveStorage *mArchiveStorage = nullptr;
 };
 
 #endif // PIMSETTINGSBACKUPRESTORE_H
