@@ -40,14 +40,13 @@ Q_SIGNALS:
     void synchronizationInstanceDone(const QString &name, const QString &identifier);
     void synchronizationInstanceFailed(const QString &);
 
-private Q_SLOTS:
+private:
     void slotSynchronizationFinished(KJob *);
     void slotNextSync();
 
-private:
     QStringList mListResources;
-    int mIndex;
-    bool mOnlyCollection;
+    int mIndex = 0;
+    bool mOnlyCollection = true;
 };
 
 #endif // SYNCHRONIZERESOURCEJOB_H
