@@ -114,7 +114,7 @@ QString Utils::infoPath()
     return QStringLiteral("information/");
 }
 
-QString Utils::adaptResourcePath(KSharedConfigPtr resourceConfig, const QString &storedData)
+QString Utils::adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData)
 {
     QString newUrl = Utils::resourcePath(resourceConfig);
     if (!newUrl.contains(QDir::homePath())) {
@@ -298,7 +298,7 @@ void Utils::storeDataExportInfo(const QString &filename, KZip *archive)
     if (QFileInfo::exists(filename)) {
         const bool fileAdded = archive->addLocalFile(filename, Utils::infoPath() + Utils::exportDataTypeFileName());
         if (fileAdded) {
-            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "exporteddata file can not add to archive" << filename;
+            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "exporteddata file can not add to archive" << filename << " to " << Utils::infoPath() + Utils::exportDataTypeFileName();
         }
     } else {
         qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "exported file was not created" << filename;
