@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -40,8 +40,8 @@ public:
 private:
     Utils::StoredTypes loadStoredTypes(int &numberOfStep);
     void saveParameters(Utils::StoredTypes type);
-    QXmlStreamWriter *mStreamWriter;
-    QXmlStreamReader *mStreamReader;
+    QXmlStreamWriter *mStreamWriter = nullptr;
+    QXmlStreamReader *mStreamReader = nullptr;
     QString mSaveTemplate;
 };
 
