@@ -29,11 +29,10 @@ public:
     explicit PimSettingExporterConfigureDialog(QWidget *parent = nullptr);
     ~PimSettingExporterConfigureDialog();
 
-private Q_SLOTS:
+private:
     void slotAccepted();
 
-private:
-    PimSettingExporterConfigureWidget *mConfigureWidget;
+    PimSettingExporterConfigureWidget *mConfigureWidget = nullptr;
 };
 
 #endif // PIMSETTINGEXPORTERCONFIGUREDIALOG_H
