@@ -36,21 +36,24 @@
 #include <ktreewidgetsearchline.h>
 
 ShowArchiveStructureDialog::ShowArchiveStructureDialog(const QString &filename, QWidget *parent)
-    : QDialog(parent),
-      mFileName(filename)
+    : QDialog(parent)
+    , mFileName(filename)
 {
     setWindowTitle(i18n("Show Archive Content on file \"%1\"", filename));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    setModal(true);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+
+    mTreeWidget = new QTreeWidget(this);
+    mTreeWidget->header()->hide();
+    mTreeWidget->setAlternatingRowColors(true);
+
+    KTreeWidgetSearchLine *searchLine = new KTreeWidgetSearchLine(this, mTreeWidget);
+    searchLine->setPlaceholderText(i18n("Search..."));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     QPushButton *user1Button = new QPushButton;
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ShowArchiveStructureDialog::reject);
-    setModal(true);
-    mTreeWidget = new QTreeWidget;
-    mTreeWidget->header()->hide();
-    mTreeWidget->setAlternatingRowColors(true);
-    KTreeWidgetSearchLine *searchLine = new KTreeWidgetSearchLine(this, mTreeWidget);
+
     mainLayout->addWidget(searchLine);
     mainLayout->addWidget(mTreeWidget);
     mainLayout->addWidget(buttonBox);
@@ -99,7 +102,6 @@ bool ShowArchiveStructureDialog::fillTree()
         searchArchiveElement(Utils::configsPath(), topDirectory, Utils::storedTypeToI18n(Utils::Config));
         searchArchiveElement(Utils::transportsPath(), topDirectory, Utils::storedTypeToI18n(Utils::MailTransport));
         searchArchiveElement(Utils::dataPath(), topDirectory, Utils::storedTypeToI18n(Utils::Data));
-        searchArchiveElement(Utils::akonadiPath(), topDirectory, Utils::storedTypeToI18n(Utils::AkonadiDb));
     }
     delete zip;
     return result;
@@ -177,4 +179,3 @@ void ShowArchiveStructureDialog::readConfig()
         resize(sizeDialog);
     }
 }
-
