@@ -32,12 +32,11 @@ public:
     void setResources(const QHash<QString, QString> &resources);
     QStringList resources() const;
 
-private Q_SLOTS:
+private:
     void slotAccepted();
     void slotSelectAll();
     void slotUnselectAll();
 
-private:
     enum DataType {
         ResourceIdentifier = Qt::UserRole + 1
     };
@@ -45,7 +44,7 @@ private:
     void readConfig();
     void writeConfig();
     void selectItem(bool state);
-    QListWidget *mListResourceWidget;
+    QListWidget *mListResourceWidget = nullptr;
 };
 
 #endif // SYNCHRONIZERESOURCEDIALOG_H
