@@ -61,13 +61,6 @@
 
 PimSettingExporterWindow::PimSettingExporterWindow(QWidget *parent)
     : KXmlGuiWindow(parent)
-    , mBackupAction(nullptr)
-    , mRestoreAction(nullptr)
-    , mSaveLogAction(nullptr)
-    , mArchiveStructureInfo(nullptr)
-    , mShowArchiveInformationsAction(nullptr)
-    , mPimSettingsBackupRestoreUI(nullptr)
-    , mTrayIcon(nullptr)
 {
     //Initialize filtermanager
     (void)MailCommon::FilterManager::instance();
@@ -175,8 +168,12 @@ void PimSettingExporterWindow::slotFullSyncInstanceFailed(const QString &identif
 
 void PimSettingExporterWindow::showFinishInformation()
 {
-    KMessageBox::information(this, i18n("For restoring data, you must use \"pimsettingexporter\". Be careful it can overwrite existing settings, data."), i18n("Backup infos."),
-                             QStringLiteral("setProgressDialogLabelBackupInfos"));
+    KMessageBox::information(
+        this,
+        i18n("For restoring data, you must use \"pimsettingexporter\". "
+             "Be careful as it can overwrite your existing settings and data."),
+        i18n("Backup"),
+        QStringLiteral("setProgressDialogLabelBackupInfos"));
     mTrayIcon->setStatus(KStatusNotifierItem::Passive);
 }
 
@@ -234,8 +231,9 @@ void PimSettingExporterWindow::setupActions(bool canZipFile)
 
 void PimSettingExporterWindow::slotConfigure()
 {
-    PimSettingExporterConfigureDialog dlg(this);
-    dlg.exec();
+    QPointer<PimSettingExporterConfigureDialog> dlg = new PimSettingExporterConfigureDialog(this);
+    dlg->exec();
+    delete dlg;
 }
 
 void PimSettingExporterWindow::slotUpdateActions(bool inAction)
@@ -257,7 +255,7 @@ void PimSettingExporterWindow::slotRestoreFile(const QUrl &url)
 
 void PimSettingExporterWindow::slotShowArchiveInformations()
 {
-    const QString filename = QFileDialog::getOpenFileName(this, i18n("Select Archive"), QString(), i18n("Zip file (*.zip)"));
+    const QString filename = QFileDialog::getOpenFileName(this, i18n("Select Archive"), QString(), QStringLiteral("%1 (*.zip)").arg(i18n("Zip file")));
     if (filename.isEmpty()) {
         return;
     }
@@ -280,7 +278,10 @@ void PimSettingExporterWindow::slotSaveLog()
 
 void PimSettingExporterWindow::slotBackupData()
 {
-    if (KMessageBox::warningContinueCancel(this, i18n("Before backing up data, it is recommended to quit all kdepim applications."), i18n("Backup")) == KMessageBox::Cancel) {
+    if (KMessageBox::warningContinueCancel(
+            this,
+            i18n("Please quit all kdepim applications before backing up your data."),
+            i18n("Backup")) == KMessageBox::Cancel) {
         return;
     }
     backupData();
@@ -353,7 +354,11 @@ void PimSettingExporterWindow::slotRestoreData()
 
 void PimSettingExporterWindow::loadData(const QString &filename, const QString &templateFile)
 {
-    if (KMessageBox::warningYesNo(this, i18n("Before to restore data, close all kdepim applications. Do you want to continue?"), i18n("Backup")) == KMessageBox::No) {
+    if (KMessageBox::warningYesNo(
+            this,
+            i18n("Before restoring data you must close all kdepim applications. "
+                 "Do you want to continue?"),
+            i18n("Backup")) == KMessageBox::No) {
         return;
     }
 
@@ -361,9 +366,13 @@ void PimSettingExporterWindow::loadData(const QString &filename, const QString &
     QString currentFileName = filename;
     if (currentFileName.isEmpty()) {
         QString recentDirClass;
-        currentFileName = QFileDialog::getOpenFileName(this, i18n("Restore backup"),
-                                                       KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///pimsettingexporter")), recentDirClass).toLocalFile(),
-                                                       i18n("Zip File (*.zip)"));
+        currentFileName
+            = QFileDialog::getOpenFileName(
+            this,
+            i18n("Restore backup"),
+            KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///pimsettingexporter")),
+                                     recentDirClass).toLocalFile(),
+            QStringLiteral("%1 (*.zip)").arg(i18n("Zip File")));
         if (currentFileName.isEmpty()) {
             return;
         }
